@@ -1,12 +1,12 @@
 package WebService::Toggl::API::Tags;
 
 use Moo;
-with 'WebService::Toggl::API', 'WebService::Toggl::Role::Set';
+with 'WebService::Toggl::Role::API', 'WebService::Toggl::Role::Set';
 use namespace::clean;
 
 sub list_of { '::Tag' }
 
-sub my_url { '/tags' }
+sub api_path { 'tags' }
 
 1;
 __END__
